function [q,d,r]=coldegree(t)

%  Decomposition of a polynomial mxn matrix according to column degrees.
%
%  [q,d,r]=coldegree(t) accepts a polynomial matrix t as an input and returns
%  q which is a leading column coefficients matrix,
%  d which is a diagonal matrix d=diag[s^a(i)/i=1:n] where a is row vector of column degrees
%  r which is a matrix whose columns are formed by the coefficients
%  of the powers deg(t,'col')-1 in the corresponding column of t and so on.
% 
%  t is written as t=q*d+r

syms s
n=size(t);
k=deg(t,'col');
m=zeros(1,n(2))*s;
for i=1:n(2)
    m(i)=s^k(i);
end
d=diag(m,0);
[q,r]=rdiv(t,d);
