function  [k,B,D,U]=lWHf(t)

% Given a mxn polynomial matrix t ,  
% this function computes the left Wiener-Hopf
% factorization T(s)=B(s)D(s)U(s), where  
% B(s) is a biproper  matrix , 
% D(s) is a diagonal matrix and 
% U(s) is a unimodular matrix ,
% and its corresponding indices k=[k1,k2,...,kr]
% r=min{m,n}.

n=size(t);
[tr,rk,u,ui]=colred(t);
h1=exchange(n(1));
h2=exchange(n(2));
k=deg(tr(:,1:min(n(1),n(2))),'col');
k=k*exchange(min(n(1),n(2)));
U=h2*ui;
if  n(1)==n(2)
    [q,d,r]=coldegree(tr);
    B=coprime((q+r*inv(d))*h1);
    D=h1*d*h2;
elseif  n(1)<n(2)
    [q,d,r]=coldegree(tr(:,1:n(1)));
    B=coprime((q+r*inv(d))*h1);
    D=[h1*d*h1 zeros(n(1),n(2)-n(1))];
else
    [q,d,r]=coldegree(tr);
    qc=complete(q);
    B=coprime((qc+r*[inv(d) zeros(n(2),n(1)-n(2))])*h1);
    D=[h2*d*h2 ; zeros(n(1)-n(2),n(2))];
end
display('t=B*D*U')