function  [k,B,D,U]=lWHfR(Nr,Dr)

% Given the numerator Nr and the denominator Dr
% of a mxn rational matrix T
% this function computes the left Wiener-Hopf
% factorization T(s)=B(s)D(s)U(s), where  
% B(s) is a biproper  matrix , 
% D(s) is a diagonal matrix and 
% U(s) is a unimodular matrix ,
% and its corresponding indices k=[k1,k2,...,kr]
% r=min{m,n}.

n=size(Nr);
t=Nr./Dr
p=plcm(Dr);
f=plcm(p);
c=deg(f);
q=s^-c*f;
N=f*t;
[kp,Bp,Dp,Up]=lWHF(N);
k=kp-c*[ones(1,min(n(1),n(2)))];
B=coprime(Bp/q);
D=coprime(s^-c*Dp);
U=Up;