function  [l,U,D,B]=rWHf(t)

% Given a mxn polynomial matrix t ,  
% this function computes the right Wiener-Hopf
% factorization T(s)=U(s)D(s)B(s), where  
% U(s) is a unimodular matrix ,
% D(s) is a diagonal matrix and 
% B(s) is a biproper  matrix , 
% and its corresponding indices l=[l1,l2,...,lr]
% r=min{m,n}.

n=size(t);
[tr,rk,u,ui]=rowred(t);
h1=exchange(n(1));
h2=exchange(n(2));
l=transpose(deg(tr(1:min(n(1),n(2)),:),'row'));
l=l*exchange(min(n(1),n(2)));
U=ui*h1;
if  n(1)==n(2)
    [d,q,r]=rowdegree(tr);
    D=h1*d*h2;
    B=coprime(h2*(q+inv(d)*r)); 
elseif  n(1)>n(2)
    [d,q,r]=rowdegree(tr(1:n(2),:));
    D=[h2*d*h2 ; zeros(n(1)-n(2),n(2))];
    B=coprime(h2*(q+inv(d)*r));
else
    [d,q,r]=rowdegree(tr);
    qc=complete(q);
    D=[h1*d*h1 zeros(n(1),n(2)-n(1))];
    B=coprime(h2*(qc+[inv(d) ; zeros(n(2)-n(1),n(1))]*r));
end
display('t=U*D*B')