function  [l,U,D,B]=rWHfR(Nr,Dr)

% Given the numerator Nr and the denominator Dr
% of a mxn rational matrix T
% this function computes the right Wiener-Hopf
% factorization T(s)=U(s)D(s)B(s), where  
% U(s) is a unimodular matrix ,
% D(s) is a diagonal matrix and 
% B(s) is a biproper  matrix ,
% and its corresponding indices l=[l1,l2,...,lr]
% r=min{m,n}.

n=size(Nr);
t=Nr./Dr
p=plcm(Dr);
f=plcm(p);
c=deg(f);
q=s^-c*f;
N=f*t;
[lp,Up,Dp,Bp]=rWHF(N);
l=lp-c*[ones(1,min(n(1),n(2)))];
U=Up;
B=coprime(Bp/q);
D=coprime(s^-c*Dp);
