function [D,Q,R]=rowdegree(t)

%  Decomposition of a polynomial mxn matrix according to row degrees.
%
%  [D,Q,R]=rowdegree(t) accepts a polynomial matrix t as an input and returns
%  D which is a diagonal matrix d=diag[s^a(i)/i=1:m] where a is column vector of row degrees
%  Q which is a leading row coefficients matrix,
%  R which is a matrix whose rows are formed by the coefficients
%  of the powers deg(t,'row')-1 in the corresponding row of t and so on.
% 
%  t is written as t=D*Q+R

syms s
n=size(t);
l=deg(t,'row');
m=zeros(n(1),1)*s;
for i=1:n(1)
    m(i)=s^l(i);
end
D=diag(m,0);
[Q,R]=ldiv(t,D);